@@ -1,19 +1,10 @@
 # Set number of data.table threads to 2
-data.table::setDTthreads(threads = 2L)
+data.table::setDTthreads(threads = 1L)
 # Set number of collapse threads to 1
 collapse::set_collapse(nthreads = 1L)
 
-test_that("Expect error", {
-  expect_error(age_years(Inf))
-  expect_error(age_years(-Inf))
-  expect_error(age_years(NaN))
-  expect_error(age_years(NULL))
-  expect_error(age_years(Sys.Date(), end = "01-01-2000"))
-})
-
 test_that("Expect zero length vector", {
   empty_values <- list(
-    # as.POSIXlt(numeric(0)),
     lubridate::Date(0),
     lubridate::POSIXct(0)
   )
